@@ -7,5 +7,6 @@ import logging
 logger = logging.getLogger(__name__)
 
 version_filename = "VERSION"
+pkg = "fk.api"
 
-__version__ = get_package_file_content(version_filename) or "0.0.0"
+__version__ = get_package_file_content(pkg, version_filename) or "0.0.0"
